@@ -45,6 +45,23 @@ CONFIG_FILE_EXT = ".json"
 CONFIG_FILE_SCHEMA = f"{CONFIG_FOLDER}/config_{SCHEMA}.json"
 CONFIG_REFRESH_RATE = "refresh_rate_seconds"
 
+# profiles
+PROFILES_FOLDER = "profiles"
+USER_PROFILES_FOLDER = f"{USER_FOLDER}/{PROFILES_FOLDER}"
+PROFILE_CONFIG_FILE = "profile.json"
+CONFIG_PROFILE = "profile"
+DEFAULT_PROFILE = "default"
+DEFAULT_PROFILE_FILE = f"{CONFIG_PROFILE}.json"
+CONFIG_NAME = "name"
+CONFIG_DESCRIPTION = "description"
+CONFIG_AVATAR = "avatar"
+CONFIG_READ_ONLY = "read_only"
+PROFILE_CONFIG = "config"
+CONFIG_ID = "id"
+PROFILE_FILE_SCHEMA = f"{CONFIG_FOLDER}/profile_{SCHEMA}.json"
+PROFILE_EXPORT_FORMAT = "zip"
+IMPORTED_PROFILE_PREFIX = "imported"
+
 # Config currencies
 CONFIG_CRYPTO_CURRENCIES = "crypto-currencies"
 CONFIG_CRYPTO_CURRENCY = "crypto-currency"
@@ -52,6 +69,41 @@ CONFIG_CRYPTO_PAIRS = "pairs"
 CONFIG_CRYPTO_QUOTE = "quote"
 CONFIG_CRYPTO_ADD = "add"
 
+# Exchange
+CONFIG_EXCHANGES = "exchanges"
+CONFIG_EXCHANGE_KEY = "api-key"
+CONFIG_EXCHANGE_SECRET = "api-secret"
+CONFIG_EXCHANGE_PASSWORD = "api-password"
+CONFIG_EXCHANGE_SANDBOXED = "sandboxed"
+CONFIG_EXCHANGE_FUTURE = "future"
+CONFIG_EXCHANGE_MARGIN = "margin"
+CONFIG_EXCHANGE_SPOT = "spot"
+CONFIG_EXCHANGE_REST_ONLY = "rest_only"
+CONFIG_EXCHANGE_WEB_SOCKET = "web-socket"
+CONFIG_EXCHANGE_ENCRYPTED_VALUES = [
+    CONFIG_EXCHANGE_KEY,
+    CONFIG_EXCHANGE_SECRET,
+    CONFIG_EXCHANGE_PASSWORD,
+]
+
+# Trader
+CONFIG_TRADING = "trading"
+CONFIG_TRADER = "trader"
+CONFIG_LOAD_TRADE_HISTORY = "load-trade-history"
+CONFIG_TRADER_RISK = "risk"
+CONFIG_TRADER_RISK_MIN = 0.05
+CONFIG_TRADER_RISK_MAX = 1
+CONFIG_TRADER_REFERENCE_MARKET = "reference-market"
+
+# Simulator
+CONFIG_SIMULATOR = "trader-simulator"
+CONFIG_STARTING_PORTFOLIO = "starting-portfolio"
+SIMULATOR_CURRENT_PORTFOLIO = "simulator_current_portfolio"
+CONFIG_SIMULATOR_FEES = "fees"
+CONFIG_SIMULATOR_FEES_MAKER = "maker"
+CONFIG_SIMULATOR_FEES_TAKER = "taker"
+CONFIG_SIMULATOR_FEES_WITHDRAW = "withdraw"
+
 # OS
 PLATFORM_DATA_SEPARATOR = ":"
 
@@ -62,6 +114,7 @@ START_PENDING_EVAL_NOTE = "0"
 
 # tentacles
 TENTACLE_DEFAULT_CONFIG = "default_config"
+CONFIG_TENTACLES_FILE = "tentacles_config.json"
 
 # terms of service
 CONFIG_ACCEPTED_TERMS = "accepted_terms"
@@ -84,10 +137,13 @@ COMMUNITY_TOPS_COUNT = 1000
 PLATFORM_DATA_SEPARATOR = ":"
 
 # default values in config files and interfaces
+DEFAULT_API_KEY = "your-api-key-here"
+DEFAULT_API_SECRET = "your-api-secret-here"
+DEFAULT_API_PASSWORD = "your-api-password-here"
 DEFAULT_CONFIG_VALUES = {
-    "your-api-key-here",
-    "your-api-secret-here",
-    "your-api-password-here",
+    DEFAULT_API_KEY,
+    DEFAULT_API_SECRET,
+    DEFAULT_API_PASSWORD,
     "NOKEY",
     "NO KEY",
     "Empty",
